/*
m_midi_pitchbend - Convert two byte MIDI pitchbend to -1 to 1 range
 - 

DESCRIPTION
Convert MIDI pitchbend information in the midiin format to a value in the
range -1 to 1.

SYNTAX
kPitchbend m_midi_pitchbend kByte1, kByte2

INITIALIZATION

PERFORMANCE
kPitchbend - Resultant pitchbend value in the range of -1 to 1
kByte1, kByte2 - The two MIDI bytes giving the pitchbend value. In Csound's
	midiin opcode these are kData1 and kData2 when kStatus is 224.

CREDITS
Author: Jeanette C.
*/

opcode m_midi_pitchbend, k, kk
	kByte1, kByte2 xin

	; Calculate the output, byte2 is multiplied by 128, then the offset must
	; be given, the result must be divided by 8192 to give the desired
	; range.
	kPitchBend = ((kByte2 * 128) + kByte1 - 8192) / 8192
	xout(kPitchBend)
endop
